clear
set more off
set matsize 1000

*Set/change working directory here if necessary.*
use "StateLegislativeElections_TermLimits.dta" 

*Generating Variables Necessary for All Subsequent Analyses
tostring dist, gen(dist_string)
tostring year, gen(year_string)
g chamber_string = "l"
replace chamber_string = "u" if lower == 0
g state_chamber = state + "_" + chamber_string
g state_year = state + "_" + year_string
g state_chamber_dist = state + "_" + chamber_string + "_" + dist_string
g state_chamber_year = state + "_" + chamber_string + "_" + year_string
g decade = "1992"
replace decade = "2002" if year >= 2002
g state_chamber_dist_decade = state_chamber_dist + "_" + decade
drop dist_string year_string chamber_string decade
g prev_winner = prev_voteshare > .5
replace prev_winner = . if prev_voteshare == .
g next_winner = next_voteshare > .5
g prev_incvoteshare = prev_voteshare
replace prev_incvoteshare = 1 - prev_voteshare if prev_voteshare < .5
g prev_uncontested = prev_incvoteshare == 1
replace prev_uncontested = . if prev_voteshare == .
g treatment = voteshare > .5
g rv1 = voteshare - .5
g rv2 = rv1^2
g rv3 = rv1^3
g rv4 = rv1^4
g int_1 = rv1*treatment
g int_2 = rv2*treatment
g int_3 = rv3*treatment
g int_4 = rv4*treatment
g absrv = abs(rv1)
g absrv2 = absrv^2
g absrv3 = absrv^3
g absrv4 = absrv^4
g exp_1 = expiring*rv1
g exp_2 = expiring*rv2
g exp_3 = expiring*rv3
g exp_4 = expiring*rv4
g int_exp_1 = exp_1*treatment
g int_exp_2 = exp_2*treatment
g int_exp_3 = exp_3*treatment
g int_exp_4 = exp_4*treatment
g treatment_expiring = treatment*expiring
g expabs_1 = expiring*absrv
g expabs_2 = expiring*absrv2
g expabs_3 = expiring*absrv3
g expabs_4 = expiring*absrv4
g winner_voteshare = voteshare
replace winner_voteshare = 1 - voteshare if voteshare < .5
g winner_category = floor(winner_voteshare*100)/100
replace winner_category = winner_category + .005
egen mean_winner_runagain_expiring = mean(winner_runagain) if expiring == 1, by(winner_category)
egen mean_winner_runagain_nonexpiring = mean(winner_runagain) if expiring == 0, by(winner_category)
sort expiring winner_category
replace mean_winner_runagain_expiring = . if winner_category == winner_category[_n-1]
replace mean_winner_runagain_nonexpiring = . if winner_category == winner_category[_n-1]
g voteshare_category = (floor(voteshare*100))/100
replace voteshare_category = .99 if voteshare_category == 1
replace voteshare_category = voteshare_category + .005
egen mean_next_voteshare_expiring = mean(next_voteshare) if expiring == 1, by(voteshare_category)
egen mean_next_voteshare_nonexpiring = mean(next_voteshare) if expiring == 0, by(voteshare_category)
egen mean_next_winner_expiring = mean(next_winner) if expiring == 1, by(voteshare_category)
egen mean_next_winner_nonexpiring = mean(next_winner) if expiring == 0, by(voteshare_category)
sort expiring voteshare_category
replace mean_next_voteshare_expiring = . if voteshare_category == voteshare_category[_n-1]
replace mean_next_voteshare_nonexpiring = . if voteshare_category == voteshare_category[_n-1]
replace mean_next_winner_expiring = . if voteshare_category == voteshare_category[_n-1]
replace mean_next_winner_nonexpiring = . if voteshare_category == voteshare_category[_n-1]

*****Table 1*****
tab state lower

*****Tables 2, A1, and A2*****
/* Note: The code below replicates our estimates in Tables 2, A1, and A2. We first run three 
regressions, which are shown in full in Tables A1 and A2. Table 2 presents only the most
relevant point estimates which are extracted from the regressions. Comments show which of
these point estimates match those in Table 2. Table 2 presents bootstrapped confidence 
intervals for each of these point estimates. The code to reproduce these bootrap procedures 
is below as well, although computational power may prevent users from completing 100,000 
bootstrap replications. 
*/
*Vote Share Regression (look at the coefficients on treatment and expiring and the sum of the two)
areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
*Vote Share, Non-expiring
disp _b[treatment]
*Vote Share, Expiring
disp _b[treatment] + _b[treatment_expiring]
*Vote Share Difference
disp -_b[treatment_expiring]
*Victory Regression (look at the coefficients on treatment and expiring and the sum of the two)
areg next_winner treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
*Victory, Non-expiring
disp _b[treatment]
*Victory, Expiring
disp _b[treatment] + _b[treatment_expiring]
*Victory Difference
disp -_b[treatment_expiring]
*Estimating Run Probabilities
areg winner_runagain absrv* expabs_* expiring, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
*Pr(Winner Runs Again), Non-expiring
disp _b[_cons]
*Pr(Winner Runs Again), Expiring
disp _b[_cons] + _b[expiring]
*Pr(Winner Runs Again), Difference
disp -_b[expiring]
*Computing Estimates of Personal and Partisan Advantages
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_victory 
disp partisan_victory
*Sample Sizes
tab expiring
/* Bootstrap for 95% Confidence Intervals
Note: This code will run 1000 bootstrap simulations, so the results may not
exactly match those in the paper. The confidence intervals in Table 2 were 
generated with 100,000 bootstrap simulations. To replicate this exactly, you 
will need significant computational power. You will need to replace "set matsize 
1000" at the top of this page with "set matsize 100000." You will have to
replace the 1000's below with 100000. Lastly, the numbers 26 and 975 should be
replaced with 2501 and 99750. */
matrix B = J(1000,15,.)
forvalues i = 1/1000{
	quietly{
		preserve
		bsample
		areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber)
		scalar rd_2 = _b[treatment]
		scalar rd_1 = _b[treatment] + _b[treatment_expiring]
		scalar rd_diff = -_b[treatment_expiring]
		areg next_winner treatment expiring treatment_expiring rv* exp_*, a(state_chamber)
		scalar rdw_2 = _b[treatment]
		scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
		scalar rdw_diff = -_b[treatment_expiring]
		areg winner_runagain absrv* expabs_* expiring, a(state_chamber)
		scalar p_2 = _b[_cons]
		scalar p_1 = _b[_cons] + _b[expiring]
		scalar p_diff = -_b[expiring]
		restore
		scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
		scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
		scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
		scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
		matrix B[`i',1] = rd_2
		matrix B[`i',2] = rd_1
		matrix B[`i',3] = rd_diff
		matrix B[`i',4] = rdw_2
		matrix B[`i',5] = rdw_1
		matrix B[`i',6] = rdw_diff
		matrix B[`i',7] = p_2
		matrix B[`i',8] = p_1
		matrix B[`i',9] = p_diff
		matrix B[`i',10] = personal_vote
		matrix B[`i',11] = partisan_vote
		matrix B[`i',12] = personal_victory
		matrix B[`i',13] = partisan_victory
		}
	if round(`i'/100) == (`i'/100){
		disp `i'
		}
	}
svmat B
/* The code below presents the boostrap estimates of the lower and upper bound for each 
point estimate in Table2. To match each number up to the relevant place in Table 2, start
at the top left of Table 2 and read across and then down. For example, the first two numbers
are the lower and upper bounds, respectively, for our RD Estimate (Vote Share) for
non-expiring cases. Then, we show the vote share estimate for expiring cases, then the
difference between the two, etc.
*/
forvalues i = 1/13 {
	sort B`i'
	sum B`i' if _n == 26
	sum B`i' if _n == 975
	}
drop B*	

****** Figure 1 ******
areg winner_runagain absrv* expabs_* expiring, a(state_chamber) robust
predict p_runagain_0 if expiring == 0
predict se_runagain_0 if expiring == 0, stdp
predict p_runagain_1 if expiring == 1
predict se_runagain_1 if expiring == 1, stdp
g upper_1 = p_runagain_1 + se_runagain_1
g upper_0 = p_runagain_0 + se_runagain_0
g lower_1 = p_runagain_1 - se_runagain_1
g lower_0 = p_runagain_0 - se_runagain_0
sort absrv
graph twoway (scatter mean_winner_runagain_expiring mean_winner_runagain_nonexpiring winner_category if winner_category < .8) (line upper_* lower_* p_runagain_* winner_voteshare if winner_voteshare < .8), xline(.5, lc(black) lw(medthin) lp(dashed))
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Winner's Vote Share
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Pr(Winner Runs Again)
gr_edit .plotregion1.plot1.style.editstyle marker(size(small)) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(fillcolor(gs8)) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(linestyle(color(gs8))) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(size(small)) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(width(medthin)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(dash)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .71 .65
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Non-expiring
gr_edit .plotregion1.AddTextBox added_text editor .08 .65
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(gs8) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Expiring
gr_edit .xaxis1.plotregion.xscale.curmin = 0.485
gr_edit .plotregion1.AddTextBox added_text editor .7483208908813712 .5176784007287064
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].style.editstyle size(medsmall) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush P0
gr_edit .plotregion1.AddTextBox added_text editor .4053414252478929 .5132128736178193
gr_edit .plotregion1.added_text_new = 4
gr_edit .plotregion1.added_text_rec = 4
gr_edit .plotregion1.added_text[4].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[4].style.editstyle size(medsmall) editcopy
gr_edit .plotregion1.added_text[4].text = {}
gr_edit .plotregion1.added_text[4].text.Arrpush P1
gr_edit .plotregion1.added_text[4].style.editstyle color(gs8) editcopy
gr_edit .plotregion1.AddLine added_lines editor .5173348986432536 .7287593244003741 .5015338027124219 .6857238781421813
gr_edit .plotregion1.added_lines_new = 1
gr_edit .plotregion1.added_lines_rec = 1
gr_edit .plotregion1.added_lines[1].style.editstyle  linestyle( width(thin) color(black) pattern(solid)) headstyle( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(medium) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) headpos(head) editcopy
gr_edit .plotregion1.AddLine added_lines editor .5121823673614607 .3949085897913613 .5018773047978749 .3766511277424307
gr_edit .plotregion1.added_lines_new = 2
gr_edit .plotregion1.added_lines_rec = 2
gr_edit .plotregion1.added_lines[2].style.editstyle  linestyle( width(thin) color(gs8) pattern(solid)) headstyle( symbol(circle) linestyle( width(thin) color(gs8) pattern(solid)) fillcolor(gs8) size(medium) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) headpos(head) editcopy
gr_edit .plotregion1.added_lines[1].drag_point = (0)
gr_edit .plotregion1.added_lines[1].DragBy .0065205221603325 -.0006870041709057
graph save "Figure1.gph", replace
drop upper_* lower_* p_* se_*


****** Figure 2 ******
areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
predict p_1 if treatment == 0 & expiring == 0
predict p_2 if treatment == 1 & expiring == 0
predict p_3 if treatment == 0 & expiring == 1
predict p_4 if treatment == 1 & expiring == 1
predict se_1 if treatment == 0 & expiring == 0, stdp
predict se_2 if treatment == 1 & expiring == 0, stdp
predict se_3 if treatment == 0 & expiring == 1, stdp
predict se_4 if treatment == 1 & expiring == 1, stdp
g upper_1 = p_1 + se_1
g upper_2 = p_2 + se_2
g upper_3 = p_3 + se_3
g upper_4 = p_4 + se_4
g lower_1 = p_1 - se_1
g lower_2 = p_2 - se_2
g lower_3 = p_3 - se_3
g lower_4 = p_4 - se_4
sort voteshare
graph twoway (scatter mean_next_voteshare_expiring mean_next_voteshare_nonexpiring voteshare_category if voteshare_category > .3 & voteshare_category < .7) (line upper_* lower_* p_* voteshare if absrv < .2), xline(.5, lc(black) lw(medthin) lp(dashed))
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Democratic Vote Share (t)
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Democratic Vote Share (t+1)
gr_edit .plotregion1.plot1.style.editstyle marker(size(small)) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(fillcolor(gs8)) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(linestyle(color(gs8))) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(size(small)) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot13.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot13.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot14.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot14.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(width(medthin)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(dash)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .6445354722245011 .5277508459899388
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Non-expiring
gr_edit .plotregion1.AddTextBox added_text editor .4123730781063585 .3144524081658784
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].style.editstyle color(gs8) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Expiring
graph save "Figure2.gph", replace
drop upper_* lower_* p_* se_*


****** Figure 3 ******
areg next_winner treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
predict p_1 if treatment == 0 & expiring == 0
predict p_2 if treatment == 1 & expiring == 0
predict p_3 if treatment == 0 & expiring == 1
predict p_4 if treatment == 1 & expiring == 1
predict se_1 if treatment == 0 & expiring == 0, stdp
predict se_2 if treatment == 1 & expiring == 0, stdp
predict se_3 if treatment == 0 & expiring == 1, stdp
predict se_4 if treatment == 1 & expiring == 1, stdp
g upper_1 = p_1 + se_1
g upper_2 = p_2 + se_2
g upper_3 = p_3 + se_3
g upper_4 = p_4 + se_4
g lower_1 = p_1 - se_1
g lower_2 = p_2 - se_2
g lower_3 = p_3 - se_3
g lower_4 = p_4 - se_4
sort voteshare
graph twoway (scatter mean_next_winner_expiring mean_next_winner_nonexpiring voteshare_category if voteshare_category > .3 & voteshare_category < .7) (line upper_* lower_* p_* voteshare if absrv < .2), xline(.5, lc(black) lw(medthin) lp(dashed))
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Democratic Vote Share (t)
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Democratic Victory (t+1)
gr_edit .plotregion1.plot1.style.editstyle marker(size(small)) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(fillcolor(gs8)) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(linestyle(color(gs8))) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(size(small)) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot13.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot13.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot14.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot14.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(width(medthin)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(dash)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .88 .53
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Non-expiring
gr_edit .plotregion1.AddTextBox added_text editor .22 .35
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].style.editstyle color(gs8) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Expiring
graph save "Figure3.gph", replace
drop upper_* lower_* p_* se_* p_*


***Table A3***
*Row 1
areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 2
areg next_voteshare treatment expiring treatment_expiring rv* exp_* prev_voteshare prev_winner, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_* prev_voteshare prev_winner, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring prev_voteshare prev_winner, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 3 
areg next_voteshare treatment expiring treatment_expiring rv* exp_* if absrv > .005, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_* if absrv > .005, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring if absrv > .005, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory 


***Table A4***
areg winner_runagain expiring absrv* expabs_*, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
*Row 1
areg next_voteshare treatment expiring treatment_expiring rv1 exp_1 if absrv < .2, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv1 exp_1 if absrv < .2, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 2
areg next_voteshare treatment expiring treatment_expiring rv1 rv2 exp_1 exp_2 if absrv < .2, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv1 rv2 exp_1 exp_2 if absrv < .2, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 3
areg next_voteshare treatment expiring treatment_expiring rv1 rv2 rv3 exp_1 exp_2 exp_3 if absrv < .5, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv1 rv2 rv3 exp_1 exp_2 exp_3 if absrv < .5, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 4
areg next_voteshare treatment expiring treatment_expiring rv* exp_* if absrv < .5, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_* if absrv < .5, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 5
areg next_voteshare treatment expiring treatment_expiring rv1 exp_1 int_1 int_exp_1 if absrv < .2, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv1 exp_1 int_1 int_exp_1 if absrv < .2, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 6
areg next_voteshare treatment expiring treatment_expiring rv1 rv2 exp_1 exp_2 int_1 int_2 int_exp_1 int_exp_2 if absrv < .2, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv1 rv2 exp_1 exp_2 int_1 int_2 int_exp_1 int_exp_2 if absrv < .2, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 7
areg next_voteshare treatment expiring treatment_expiring rv1 rv2 rv3 exp_1 exp_2 exp_3 int_1 int_2 int_3 int_exp_1 int_exp_2 int_exp_3 if absrv < .5, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv1 rv2 rv3 exp_1 exp_2 exp_3 int_1 int_2 int_3 int_exp_1 int_exp_2 int_exp_3 if absrv < .5, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 8
areg next_voteshare treatment expiring treatment_expiring rv* exp_* int_* int_exp_* if absrv < .5, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_* int_* int_exp_* if absrv < .5, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory
*Row 9 (for this step, you must download the rdrobust package using the code below)
net install rdrobust, from(http://www-personal.umich.edu/~cattaneo/rdrobust/stata) replace
gen run_again3 = 0
replace run_again3 = 1 if winner_runagain == 1 & voteshare > .5
replace run_again3 = -1 if winner_runagain == 1 & voteshare < .5
quietly{
	xi: reg next_voteshare i.state_chamber
	predict res, r
	xi: reg next_winner i.state_chamber
	predict res_winner, r
	xi: reg run_again3 i.state_chamber
	predict res_runagain, r	
}

rdrobust res rv1 if expiring == 0
scalar rd_2 = e(tau_cl)
rdrobust res rv1 if expiring == 1
scalar rd_1 = e(tau_cl)
rdrobust res_winner rv1 if expiring == 0
scalar rdw_2 = e(tau_cl)
rdrobust res_winner rv1 if expiring == 1
scalar rdw_1 = e(tau_cl)
rdrobust res_runagain rv1 if expiring == 0
scalar p_2 = e(tau_cl) / 2
rdrobust res_runagain rv1 if expiring == 1
scalar p_1 = e(tau_cl) / 2
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
disp personal_victory 
disp partisan_victory

***Table A5***
areg prev_voteshare expiring, a(state_chamber) robust
areg prev_voteshare expiring rv*, a(state_chamber) robust
areg prev_winner expiring, a(state_chamber) robust
areg prev_winner expiring rv*, a(state_chamber) robust
areg prev_incvoteshare expiring, a(state_chamber) robust
areg prev_incvoteshare expiring rv*, a(state_chamber) robust
areg prev_uncontested expiring, a(state_chamber) robust
areg prev_uncontested expiring rv*, a(state_chamber) robust

***Table A6***
reg next_voteshare treatment rv* if absrv < .1, robust
reg prev_voteshare treatment rv* if absrv < .1, robust
reg next_voteshare treatment rv* prev_voteshare prev_winner if absrv < .1, robust
reg next_voteshare treatment rv* if absrv < .1 & absrv > .005, robust
reg next_winner treatment rv* if absrv < .1, robust
reg prev_winner treatment rv* if absrv < .1, robust
reg next_winner treatment rv* prev_voteshare prev_winner if absrv < .1, robust
reg next_winner treatment rv* if absrv < .1 & absrv > .005, robust

***Table A7 and Figure A3***
/* To conduct the McCrary tests, download the DCdensity .ado file from
http://eml.berkeley.edu/~jmccrary/DCdensity/. In order to make the exact
formatting of Figure A3, we modified this .ado file. Pleae contact the authors
if you are interested in replicating the exact style of the figure. */
gen inc_share = .
replace inc_share = voteshare if prev_voteshare > .5
replace inc_share = 1-voteshare if prev_voteshare < .5
gen inc_rv = inc_share - .5
preserve
DCdensity rv1, breakpoint(0) generate(a b c d e) graphname(DCdensity_dem_full.pdf)
restore
preserve
keep if expiring == 0
DCdensity rv1, breakpoint(0) generate(a b c d e) graphname(DCdensity_dem_nonexpiring.pdf)
restore
preserve
keep if expiring == 1
DCdensity rv1, breakpoint(0) generate(a b c d e) graphname(DCdensity_dem_expiring.pdf)
restore
preserve
DCdensity inc_rv, breakpoint(0) generate(a b c d e) graphname(DCdensity_inc_full.pdf)
restore
preserve
keep if expiring == 0
DCdensity inc_rv, breakpoint(0) generate(a b c d e) graphname(DCdensity_inc_nonexpiring.pdf)
restore
preserve
keep if expiring == 1
DCdensity inc_rv, breakpoint(0) generate(a b c d e) graphname(DCdensity_inc_expiring.pdf)
restore

***Table A9***
egen minvote = min(voteshare), by(state_chamber_dist)
egen maxvote = max(voteshare), by(state_chamber_dist)
egen meanvote = mean(voteshare), by(state_chamber_dist)
g competitive = minvote < .5 & maxvote > .5
preserve
sort state_chamber_dist
drop if state_chamber_dist == state_chamber_dist[_n-1]
*proportion of districts that elected both parties in study period
sum competitive
restore
g closerace = absrv < .02
egen closeonce = max(closerace), by(state_chamber_dist)
*distribution of mean vote share for districts that had at least one close race
sum meanvote if closeonce == 1, d
g extreme = meanvote > .55 | meanvote < .45
*Row 1
areg next_voteshare treatment expiring treatment_expiring rv* exp_* if extreme == 0, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring if extreme == 0, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
matrix B = J(1000, 2, .)
forvalues i = 1/1000 {
	quietly {
		preserve
		keep if extreme == 0
		bsample
		areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
		scalar rd_2 = _b[treatment]
		scalar rd_1 = _b[treatment] + _b[treatment_expiring]
		areg winner_runagain absrv* expabs_* expiring, a(state_chamber) robust
		scalar p_2 = _b[_cons]
		scalar p_1 = _b[_cons] + _b[expiring]
		scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
		scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
		matrix B[`i', 1] = personal_vote 
		matrix B[`i', 2] = partisan_vote
		restore
		}
	if round(`i'/100) == (`i'/100) {
		disp `i'
		}
}
svmat B
forvalues i = 1/2 {
sort B`i'
sum B`i' if _n == 26
sum B`i' if _n == 975
}
drop B*
*Row 2
areg next_voteshare treatment expiring treatment_expiring rv* exp_* if extreme == 1, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring if extreme == 1, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
matrix B = J(1000, 2, .)
forvalues i = 1/1000 {
	quietly {
		preserve
		keep if extreme == 1
		bsample
		areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
		scalar rd_2 = _b[treatment]
		scalar rd_1 = _b[treatment] + _b[treatment_expiring]
		areg winner_runagain absrv* expabs_* expiring, a(state_chamber) robust
		scalar p_2 = _b[_cons]
		scalar p_1 = _b[_cons] + _b[expiring]
		scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
		scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
		matrix B[`i', 1] = personal_vote 
		matrix B[`i', 2] = partisan_vote
		restore
		}
	if round(`i'/100) == (`i'/100) {
		disp `i'
		}
}
svmat B
forvalues i = 1/2 {
sort B`i'
sum B`i' if _n == 26
sum B`i' if _n == 975
}
drop B*


***Table A10***
egen minyear = min(year), by(state_chamber)
g firstyear =  year == minyear
areg next_voteshare treatment expiring treatment_expiring rv* exp_* if firstyear == 0, a(state_chamber) robust
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
*Vote Share, Non-expiring
disp _b[treatment]
*Vote Share, Expiring
disp _b[treatment] + _b[treatment_expiring]
*Vote Share Difference
disp -_b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_* if firstyear == 0, a(state_chamber) robust
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
*Victory, Non-expiring
disp _b[treatment]
*Victory, Expiring
disp _b[treatment] + _b[treatment_expiring]
*Victory Difference
disp -_b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring if firstyear == 0, a(state_chamber) robust
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
*Pr(Winner Runs Again), Non-expiring
disp _b[_cons]
*Pr(Winner Runs Again), Expiring
disp _b[_cons] + _b[expiring]
*Pr(Winner Runs Again), Difference
disp -_b[expiring]
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
disp personal_vote 
disp partisan_vote
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
disp personal_victory 
disp partisan_victory
*Bootstrap for Standard Errors
matrix B = J(1000,13,.)
forvalues i = 1/1000{
quietly{
preserve
bsample
areg next_voteshare treatment expiring treatment_expiring rv* exp_* if firstyear == 0, a(state_chamber)
scalar rd_2 = _b[treatment]
scalar rd_1 = _b[treatment] + _b[treatment_expiring]
scalar rd_diff = -_b[treatment_expiring]
areg next_winner treatment expiring treatment_expiring rv* exp_* if firstyear == 0, a(state_chamber)
scalar rdw_2 = _b[treatment]
scalar rdw_1 = _b[treatment] + _b[treatment_expiring]
scalar rdw_diff = -_b[treatment_expiring]
areg winner_runagain absrv* expabs_* expiring if firstyear == 0, a(state_chamber)
scalar p_2 = _b[_cons]
scalar p_1 = _b[_cons] + _b[expiring]
scalar p_diff = -_b[expiring]
restore
scalar personal_vote = (rd_2 - rd_1)/(2*(p_2 - p_1))
scalar partisan_vote = (rd_2/2) - (p_2*(rd_2 - rd_1))/(2*(p_2 - p_1))
scalar personal_victory = (rdw_2 - rdw_1)/(2*(p_2 - p_1))
scalar partisan_victory = (rdw_2/2) - (p_2*(rdw_2 - rdw_1))/(2*(p_2 - p_1))
matrix B[`i',1] = rd_2
matrix B[`i',2] = rd_1
matrix B[`i',3] = rd_diff
matrix B[`i',4] = rdw_2
matrix B[`i',5] = rdw_1
matrix B[`i',6] = rdw_diff
matrix B[`i',7] = p_2
matrix B[`i',8] = p_1
matrix B[`i',9] = p_diff
matrix B[`i',10] = personal_vote
matrix B[`i',11] = partisan_vote
matrix B[`i',12] = personal_victory
matrix B[`i',13] = partisan_victory
}
if round(`i'/100) == (`i'/100){
disp `i'
}
}
svmat B
forvalues i = 1/13{
sort B`i'
 sum B`i' if _n == 26
 sum B`i' if _n == 975
}
drop B*

***Table A8 -- Replicating Previous Estimates***
*State Legislatures w/ Term Limits
g winner_seniority = dem_seniority
replace winner_seniority = rep_seniority if voteshare < .5
g winner_next = next_voteshare
replace winner_next = 1 - next_voteshare if voteshare < .5
g incumbency = 0 
replace incumbency = 1 if voteshare > .5 & dem_runagain == 1
replace incumbency = -1 if voteshare < .5 & rep_runagain == 1
*Sophomore Surge
ttest winner_next == winner_voteshare if winner_seniority == 0 & winner_runagain == 1
*Retirement Slump
ttest winner_next == winner_voteshare if winner_runagain == 0
*Panel Regression
xi:areg next_voteshare incumbency i.state_chamber_year, a(state_chamber_dist_decade) cluster(state_chamber_dist_decade)
*Regression Discontinuity
reg next_voteshare treatment rv* if absrv < .1, robust
*U.S. House
clear
set more off
use "House.dta"
*Sophomore Surge
ttest inc_voteshare = lag_inc_voteshare if sophomore == 1
*Retirement Slump
ttest inc_voteshare = lag_inc_voteshare if openseat == 1
*Panel Regression
xi:areg voteshare incumbency i.year, a(state_district_period) cluster(state_district)
*Regression Discontinuity
reg voteshare treatment rv*, robust

***Placebo Analyses for States Without Term Limits**
clear
set more off
use "StateLegislativeElections_NoTermLimits.dta" 
g next_winner = next_voteshare > .5
tab expiring
g treatment = voteshare > .5
g rv1 = voteshare - .5
g rv2 = rv1^2
g rv3 = rv1^3
g rv4 = rv1^4
g int1 = rv1*treatment
g int2 = rv2*treatment
g int3 = rv3*treatment
g int4 = rv4*treatment
g absrv = abs(rv1)
g absrv2 = absrv^2
g absrv3 = absrv^3
g absrv4 = absrv^4
g exp_1 = expiring*rv1
g exp_2 = expiring*rv2
g exp_3 = expiring*rv3
g exp_4 = expiring*rv4
g treatment_expiring = treatment*expiring
g chamber_string = "l"
replace chamber_string = "u" if lower == 0
g state_chamber = state + "_" + chamber_string
*Figure A1
areg next_voteshare treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
predict p_1 if treatment == 0 & expiring == 0
predict p_2 if treatment == 1 & expiring == 0
predict p_3 if treatment == 0 & expiring == 1
predict p_4 if treatment == 1 & expiring == 1
predict se_1 if treatment == 0 & expiring == 0, stdp
predict se_2 if treatment == 1 & expiring == 0, stdp
predict se_3 if treatment == 0 & expiring == 1, stdp
predict se_4 if treatment == 1 & expiring == 1, stdp
g upper_1 = p_1 + se_1
g upper_2 = p_2 + se_2
g upper_3 = p_3 + se_3
g upper_4 = p_4 + se_4
g lower_1 = p_1 - se_1
g lower_2 = p_2 - se_2
g lower_3 = p_3 - se_3
g lower_4 = p_4 - se_4
sort voteshare
graph twoway line upper_* lower_* p_* voteshare if absrv < .2, xline(.5, lc(black) lw(medthin) lp(dashed))
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Democratic Vote Share (t)
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Democratic Vote Share (t+1)
gr_edit .plotregion1.plot1.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(width(medthin)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(dash)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .7 .53
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Non-expiring
gr_edit .plotregion1.AddTextBox added_text editor .6 .56
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].style.editstyle color(gs8) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Expiring
graph save "FigureA1.gph", replace
drop p_* se_* upper_* lower_*

*Figure A2
areg next_winner treatment expiring treatment_expiring rv* exp_*, a(state_chamber) robust
predict p_1 if treatment == 0 & expiring == 0
predict p_2 if treatment == 1 & expiring == 0
predict p_3 if treatment == 0 & expiring == 1
predict p_4 if treatment == 1 & expiring == 1
predict se_1 if treatment == 0 & expiring == 0, stdp
predict se_2 if treatment == 1 & expiring == 0, stdp
predict se_3 if treatment == 0 & expiring == 1, stdp
predict se_4 if treatment == 1 & expiring == 1, stdp
g upper_1 = p_1 + se_1
g upper_2 = p_2 + se_2
g upper_3 = p_3 + se_3
g upper_4 = p_4 + se_4
g lower_1 = p_1 - se_1
g lower_2 = p_2 - se_2
g lower_3 = p_3 - se_3
g lower_4 = p_4 - se_4
sort voteshare
graph twoway line upper_* lower_* p_* voteshare if absrv < .2, xline(.5, lc(black) lw(medthin) lp(dashed))
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Democratic Vote Share (t)
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Democratic Victory (t+1)
gr_edit .plotregion1.plot1.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot10.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot11.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(color(gs8)) editcopy
gr_edit .plotregion1.plot12.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(width(medthin)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(dash)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .95 .53
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Non-expiring
gr_edit .plotregion1.AddTextBox added_text editor .83 .59
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].style.editstyle color(gs8) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Expiring
graph save "FigureA2.gph", replace
