#### Replication Code for Statistical Simulations
#### Fowler and Hall, QJPS

# Set working directory
setwd("~/Dropbox/Fowler-Hall/State RD/")

# Set seed for simulations
set.seed(02138)

# Sample size for simulations
n <- 10000

# Initial simulation: variance equal across parties
sd.r <- 1
sd.d <- 1

# error variance
sd.e <- 2

#### first, draw quality
q.r <- rnorm(n=n, mean=0, sd=sd.r)
q.d <- rnorm(n=n, mean=0, sd=sd.d)

#### party adv fixed
N <- 4


### draw error
e <- rnorm(n=n, mean=0, sd=sd.e)

#### calc vote share
V.dem <- q.d - q.r + N + e

#### calc mean quality for each "election"
mean.qual <- (q.d + q.r)/2

### verify analytic solution from proof
mean.dem.qual <- mean(q.d[abs(V.dem) < .1])

answer <- (-N)/(2+((sd.e^2)/(sd.d^2)))

### these are approximately equal
### won't be exactly equal because of simulation error
### and because we are calculating average within small window
### and not only exactly at the discontinuity
### since Pr{V.dem == 0} = 0
mean.dem.qual
answer


### create plot for appendix
pdf(file="qual_sim_norm.pdf")
plot(x=V.dem, y=mean.qual, col="darkgray", cex=.8, xlab="Dem Vote Share Winning Margin", ylab="Average Candidate Quality")
abline(v=0)
abline(h=0, lty=2)
lines(loess.smooth(x=V.dem, y=mean.qual), col="red")
dev.off()

##### Next simulation: unequal variances

set.seed(02138)

n <- 10000

#### Now make sd larger for Republicans
sd.r <- 3
sd.d <- 1
sd.e <- 2

#### first, draw quality
q.r <- rnorm(n=n, mean=0, sd=sd.r)
q.d <- rnorm(n=n, mean=0, sd=sd.d)


#### party adv fixed
N <- 4

# draw error
e <- rnorm(n=n, mean=0, sd=2)

#### calc vote share
V.dem <- q.d - q.r + N + e

# mean qual
mean.qual <- (q.d + q.r)/2


#### test analytic answer
mean.dem.qual <- mean(q.d[abs(V.dem) < .1])

answer <- (-N)/((1/(sd.d^2) + (1/(sd.r^2 + sd.e^2))) * (sd.r^2 + sd.e^2))

# see comment from previous simulation
mean.dem.qual
answer


pdf(file="qual_sim_norm_unequal.pdf")
plot(x=V.dem, y=mean.qual, col="darkgray", cex=.8, xlab="Dem Vote Share Winning Margin", ylab="Average Candidate Quality")
abline(v=0)
abline(h=0, lty=2)
lines(loess.smooth(x=V.dem, y=mean.qual), col="red")
dev.off()



#### Final simulation: unequal variances with random normal vote



set.seed(02138)

n <- 10000
sd.r <- 3
sd.d <- 1
sd.e <- 2

#### first, draw quality
q.r <- rnorm(n=n, mean=0, sd=sd.r)
q.d <- rnorm(n=n, mean=0, sd=sd.d)


#### party adv drawn from bimodal mixture of normals
N1 <- rnorm(n=n, mean=-4, sd=1)
N2 <- rnorm(n=n, mean=4, sd=1)
c <- rbinom(n=n, size=1, prob=.5)
N <- ifelse(c==1, N1, N2)

### draw error
e <- rnorm(n=n, mean=0, sd=2)

#### calc vote share
V.dem <- q.d - q.r + N + e

mean.qual <- (q.d + q.r)/2

pdf(file="qual_sim_n_varies.pdf")
plot(x=V.dem, y=mean.qual, col="darkgray", cex=.8, xlab="Dem Vote Share Winning Margin", ylab="Average Candidate Quality")
abline(v=0)
abline(h=0, lty=2)
lines(loess.smooth(x=V.dem, y=mean.qual), col="red")
dev.off()